@@ -1,4 +1,4 @@
-## ---- results = "asis", echo = FALSE------------------------------------------
+## ----results = "asis", echo = FALSE-------------------------------------------
 
 # output format should be of the form
 #> output
@@ -12,7 +12,8 @@ set.seed(123)
 # get the path of the parent document
 # path = names(knitr::opts_knit$get("encoding"))[1]
 base = knitr::opts_knit$get("output.dir")
-file = sys.frame(min(grep("knit", sapply(sys.calls(), function(x) as.character(x)[1]))))$input
+file = sys.frame(min(grep("^knitr::knit$|^knit$", sapply(sys.calls(), function(x) as.character(x)[1]))))$input
+file = basename(file)
 path = file.path(base, file)
 rpath = gsub("\\.[^.]*$", ".R", path)
 
@@ -73,9 +74,9 @@ linkify = function(info, title) {
 for (idx in seq_along(fileinfolist)) {
   content = fileinfolist[[sort(names(fileinfolist))[idx]]]
   if (!is.null(content$compact)) {
-    if (paste(content$main$title, "(No Output)") != content$compact$title) {
-      stop(sprintf("File %s and its compact version %s have incompatible titles\nThe compact version must be paste(main_title, \"(No Output)\")",
-        content$main$url, content$compact$url))
+    if (paste(sub("[0-9]\\. ", "", content$main$title), "(No Output)") != sub("^z ", "", content$compact$title)) {
+      stop(sprintf("File %s and its compact version %s have incompatible titles\nThe compact version must be paste(main_title, \"(No Output)\"). Is: '%s', expected: '%s'",
+        content$main$url, content$compact$url, content$compact$title, paste(content$main$title, "(No Output)")))
     }
     line = sprintf("%s (%s)", linkify(content$main, content$main$title), linkify(content$compact, "compact version"))
   } else {
@@ -178,7 +179,7 @@ for (pfunc in grep("print\\.", ls(asNamespace("mlr")), value = TRUE)) {
 
 
 
-## ---- eval = TRUE, echo = FALSE, results = 'asis'-----------------------------
+## ----eval = TRUE, echo = FALSE, results = 'asis'------------------------------
 printToc(4)
 
 ## -----------------------------------------------------------------------------
@@ -337,7 +338,7 @@ cpo = xmpPcaFunc(2)
 ## -----------------------------------------------------------------------------
 getCPOTrainedState(retrafo(trafd))$pcr$x
 
-## ---- eval = FALSE------------------------------------------------------------
+## ----eval = FALSE-------------------------------------------------------------
 #  c(response = "response", se = "prob")
 
 ## -----------------------------------------------------------------------------
@@ -509,7 +510,7 @@ retr = retrafo(trafd)
 predict.traf = predict.task %>>% retr
 getTaskTargets(predict.traf)
 
-## ---- warnings = FALSE--------------------------------------------------------
+## ----warnings = FALSE---------------------------------------------------------
 model = train("regr.lm", trafd)
 pred = predict(model, predict.traf)
 pred
@@ -517,7 +518,7 @@ pred
 ## -----------------------------------------------------------------------------
 invert(inverter(predict.traf), pred)
 
-## ---- warnings = FALSE--------------------------------------------------------
+## ----warnings = FALSE---------------------------------------------------------
 model = train("regr.lm", train.task)
 predict(model, predict.task)
 
@@ -551,7 +552,7 @@ retr = retrafo(trafd)
 predict.traf = predict.task %>>% retr
 getTaskTargets(predict.traf)
 
-## ---- warnings = FALSE--------------------------------------------------------
+## ----warnings = FALSE---------------------------------------------------------
 model = train("regr.lm", trafd)
 pred = predict(model, predict.traf)
 pred
@@ -611,7 +612,7 @@ inv = invert(inverter(trafd), 1:6)
 ## -----------------------------------------------------------------------------
 inv = invert(inverter(retrafd), 1:6)
 
-## ---- echo = FALSE------------------------------------------------------------
+## ----echo = FALSE-------------------------------------------------------------
 oscipen = options("scipen")
 options(scipen = 10)
 
@@ -643,6 +644,6 @@ pvals = c(
 
 round(p.adjust(pvals), 3)
 
-## ---- echo = FALSE------------------------------------------------------------
+## ----echo = FALSE-------------------------------------------------------------
 options(scipen = oscipen$scipen)
 
